# `narwhals.Expr`

::: narwhals.Expr
    handler: python
    options:
      members:
        - alias
        - all
        - any
        - cast
        - cum_sum
        - diff
        - drop_nulls
        - fill_null
        - filter
        - is_between
        - is_duplicated
        - is_first_distinct
        - is_in
        - is_last_distinct
        - is_null
        - is_unique
        - max
        - mean
        - min
        - null_count
        - n_unique
        - over
        - quantile
        - sample
        - shift
        - sort
        - std
        - sum
        - unique
      show_source: false
      show_bases: false
